==> wpewebkit_2.28.4.orig.tar.xz: wpewebkit-2.28.4/Source/WebKit/Shared/Databases/IndexedDB/WebIDBResult.cpp <==
/*
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebIDBResult.h"

#if ENABLE(INDEXED_DATABASE)

#include "WebCoreArgumentCoders.h"

namespace WebKit {

void WebIDBResult::encode(IPC::Encoder& encoder) const
{
    m_resultData.encode(encoder);
    m_handles.encode(encoder);
}

bool WebIDBResult::decode(IPC::Decoder& decoder, WebIDBResult& result)
{
    Optional<WebCore::IDBResultData> resultData;
    decoder >> resultData;
    if (!resultData)
        return false;
    result.m_resultData = WTFMove(*resultData);

    Optional<SandboxExtension::HandleArray> handles;
    decoder >> handles;
    if (!handles)
        return false;
    result.m_handles = WTFMove(*handles);

    return true;
}

} // namespace WebKit

#endif // ENABLE(INDEXED_DATABASE)

==> wpewebkit_2.36.0.orig.tar.xz: wpewebkit-2.36.0/Source/WebKit/Shared/Databases/IndexedDB/WebIDBResult.cpp <==
/*
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebIDBResult.h"

#include "WebCoreArgumentCoders.h"

namespace WebKit {

void WebIDBResult::encode(IPC::Encoder& encoder) const
{
    encoder << m_resultData;
    encoder << m_handles;
}

bool WebIDBResult::decode(IPC::Decoder& decoder, WebIDBResult& result)
{
    std::optional<WebCore::IDBResultData> resultData;
    decoder >> resultData;
    if (!resultData)
        return false;
    result.m_resultData = WTFMove(*resultData);

    std::optional<Vector<SandboxExtension::Handle>> handles;
    decoder >> handles;
    if (!handles)
        return false;
    result.m_handles = WTFMove(*handles);

    return true;
}

} // namespace WebKit
